@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2021  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -270,6 +270,14 @@ bool CommandApplyChanges::run() {
         // object first and then only copy this last version of any object
         // to the output.
         m_vout << "Sorting change data...\n";
+
+        // This is needed for a special case: When change files have been
+        // created from extracts it is possible that they contain objects
+        // with the same type, id, version, and timestamp. In that case we
+        // still want to get the last object available. So we have to make
+        // sure it appears first in the objects vector before doing the
+        // stable sort.
+        std::reverse(objects.ptr_begin(), objects.ptr_end());
         objects.sort(osmium::object_order_type_id_reverse_version{});
 
         if (m_locations_on_ways) {
