@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2021  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -358,10 +358,14 @@ void CommandExtract::parse_config_file() {
                 }
                 for (auto it = value.MemberBegin(); it != value.MemberEnd(); ++it) {
                     const auto& member_value = it->value;
-                    if (!member_value.IsString()) {
-                        throw config_error{"Values in 'output_header' object must be strings."};
+                    if (member_value.IsNull()) {
+                        extract.add_header_option(it->name.GetString());
+                    } else {
+                        if (!member_value.IsString()) {
+                            throw config_error{"Values in 'output_header' object must be strings or null."};
+                        }
+                        extract.add_header_option(it->name.GetString(), member_value.GetString());
                     }
-                    extract.add_header_option(it->name.GetString(), member_value.GetString());
                 }
             }
         } catch (const config_error& e) {
@@ -476,7 +480,7 @@ bool CommandExtract::setup(const std::vector<std::string>& arguments) {
             warning("Ignoring --output-format/-f option.\n");
         }
         m_config_file_name = vm["config"].as<std::string>();
-        auto slash = m_config_file_name.find_last_of('/');
+        const auto slash = m_config_file_name.find_last_of('/');
         if (slash != std::string::npos) {
             m_config_directory = m_config_file_name;
             m_config_directory.resize(slash + 1);
@@ -488,6 +492,9 @@ bool CommandExtract::setup(const std::vector<std::string>& arguments) {
             warning("Ignoring --directory/-d option.\n");
         }
         check_output_file();
+        if (m_with_history) {
+            m_output_file.set_has_multiple_object_versions(true);
+        }
         m_extracts.emplace_back(new ExtractBBox{m_output_file, "", parse_bbox(vm["bbox"].as<std::string>(), "--box/-b")});
     }
 
@@ -496,6 +503,9 @@ bool CommandExtract::setup(const std::vector<std::string>& arguments) {
             warning("Ignoring --directory/-d option.\n");
         }
         check_output_file();
+        if (m_with_history) {
+            m_output_file.set_has_multiple_object_versions(true);
+        }
         m_extracts.emplace_back(new ExtractPolygon{m_output_file, "", m_buffer, parse_multipolygon_object("./", vm["polygon"].as<std::string>(), "", m_buffer)});
     }
 
@@ -551,7 +561,7 @@ void CommandExtract::show_extracts() {
                 } else {
                     m_vout << "                  ";
                 }
-                m_vout << opt.first << ": " << opt.second << '\n';
+                m_vout << opt << '\n';
             }
         }
         m_vout << "     Envelope:    " << e->envelope_as_text() << '\n';
@@ -584,11 +594,12 @@ bool CommandExtract::run() {
     m_strategy->show_arguments(m_vout);
 
     osmium::io::Header header;
+    osmium::io::Header input_header;
     if (m_input_file.filename().empty()) {
         setup_header(header);
     } else {
         osmium::io::Reader reader{m_input_file, osmium::osm_entity_bits::nothing};
-        osmium::io::Header input_header{reader.header()};
+        input_header = reader.header();
         setup_header(header, input_header);
         reader.close();
     }
@@ -602,9 +613,7 @@ bool CommandExtract::run() {
         if (m_set_bounds) {
             file_header.add_box(extract->envelope());
         }
-        for (const auto& p : extract->header_options()) {
-            file_header.set(p.first, p.second);
-        }
+        init_header(file_header, input_header, extract->header_options());
         extract->open_file(file_header, m_output_overwrite, m_fsync);
     }
 
