@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2021  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -227,7 +227,7 @@ static void print_missing_ids(const char* type, const osmium::index::IdSetDense<
         return;
     }
     std::cerr << "Missing " << type << " IDs:";
-    for (const auto& id : set) {
+    for (const auto id : set) {
         std::cerr << ' ' << id;
     }
     std::cerr << '\n';
