@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2021  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -154,6 +154,7 @@ void CommandTagsFilter::show_arguments() {
 
     m_vout << "  other options:\n";
     m_vout << "    add referenced objects: " << yes_no(m_add_referenced_objects);
+    m_vout << "    invert match: " << yes_no(m_invert_match);
     if (m_add_referenced_objects) {
         m_vout << "    remove tags on non-matching objects: " << yes_no(m_remove_tags);
     }
@@ -334,24 +335,7 @@ void CommandTagsFilter::find_referenced_objects() {
     m_vout << "Done following references.\n";
 }
 
-bool CommandTagsFilter::run() {
-    m_vout << "Opening input file to get header...\n";
-    osmium::io::Reader reader_only_for_header{m_input_file, osmium::osm_entity_bits::nothing};
-
-    m_vout << "Opening output file...\n";
-    osmium::io::Header header{reader_only_for_header.header()};
-    setup_header(header);
-    reader_only_for_header.close();
-
-    osmium::io::Writer writer{m_output_file, header, m_output_overwrite, m_fsync};
-
-    if (m_add_referenced_objects) {
-        find_referenced_objects();
-    }
-
-    m_vout << "Opening input file...\n";
-    osmium::io::Reader reader{m_input_file, get_needed_types()};
-
+void CommandTagsFilter::copy_matching_objects(osmium::io::Reader& reader, osmium::io::Writer& writer) {
     m_vout << "Copying matching objects to output file...\n";
     ++m_count_passes;
     osmium::ProgressBar progress_bar{reader.file_size(), display_progress()};
@@ -377,10 +361,42 @@ bool CommandTagsFilter::run() {
 
     m_vout << "Closing input file...\n";
     reader.close();
+}
+
+bool CommandTagsFilter::run() {
+    if (m_add_referenced_objects) {
+        m_vout << "Opening input file to get header...\n";
+        osmium::io::Reader reader_only_for_header{m_input_file, osmium::osm_entity_bits::nothing};
+
+        m_vout << "Opening output file...\n";
+        osmium::io::Header header{reader_only_for_header.header()};
+        setup_header(header);
+        reader_only_for_header.close();
+
+        osmium::io::Writer writer{m_output_file, header, m_output_overwrite, m_fsync};
+
+        find_referenced_objects();
+
+        m_vout << "Opening input file...\n";
+        osmium::io::Reader reader{m_input_file, get_needed_types()};
+
+        copy_matching_objects(reader, writer);
+    } else {
+        m_vout << "Opening input file...\n";
+        osmium::io::Reader reader{m_input_file, get_needed_types()};
+
+        m_vout << "Opening output file...\n";
+        osmium::io::Header header{reader.header()};
+        setup_header(header);
+
+        osmium::io::Writer writer{m_output_file, header, m_output_overwrite, m_fsync};
+
+        copy_matching_objects(reader, writer);
+    }
 
     show_memory_used();
 
-    m_vout << "Needed " << m_count_passes << " passes through the input file.\n";
+    m_vout << "Needed " << m_count_passes << " pass(es) through the input file.\n";
     m_vout << "Done.\n";
 
     return true;
