@@ -21,6 +21,7 @@
 #include "command_renumber.hpp"
 #include "command_show.hpp"
 #include "command_sort.hpp"
+#include "command_tags_count.hpp"
 #include "command_tags_filter.hpp"
 #include "command_time_filter.hpp"
 
@@ -104,6 +105,10 @@ void register_commands(CommandFactory& cmd_factory) {
         return new CommandSort{cmd_factory};
     });
 
+    cmd_factory.register_command("tags-count", "Count OSM tags", [&]() {
+        return new CommandTagsCount{cmd_factory};
+    });
+
     cmd_factory.register_command("tags-filter", "Filter OSM data based on tags", [&]() {
         return new CommandTagsFilter{cmd_factory};
     });
