@@ -6,7 +6,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2021  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@ class Extract {
 
     osmium::io::File m_output_file;
     std::string m_description;
-    std::vector<std::pair<std::string, std::string>> m_header_options;
+    std::vector<std::string> m_header_options;
     osmium::Box m_envelope;
     std::unique_ptr<osmium::io::Writer> m_writer;
 
@@ -71,11 +71,15 @@ public:
         return m_envelope;
     }
 
-    void add_header_option(const std::string& name, const std::string& value) {
-        m_header_options.emplace_back(name, value);
+    void add_header_option(const std::string& option) {
+        m_header_options.emplace_back(option + "!");
     }
 
-    const std::vector<std::pair<std::string, std::string>>& header_options() const noexcept {
+    void add_header_option(const std::string& name, const std::string& value) {
+        m_header_options.emplace_back(name + "=" + value);
+    }
+
+    const std::vector<std::string>& header_options() const noexcept {
         return m_header_options;
     }
 
