@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2021  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -88,8 +88,8 @@ void PolyFileParser::parse_ring() {
         }
 
         std::istringstream sstr{line()};
-        double lon;
-        double lat;
+        double lon = NAN;
+        double lat = NAN;
         if (!(sstr >> lon >> lat)) {
             error("Expected coordinates or 'END' to end the ring.");
         }
