@@ -3,7 +3,7 @@
 Osmium -- OpenStreetMap data manipulation command line tool
 https://osmcode.org/osmium-tool/
 
-Copyright (C) 2013-2020  Jochen Topf <jochen@topf.org>
+Copyright (C) 2013-2021  Jochen Topf <jochen@topf.org>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -212,9 +212,8 @@ void with_osm_output::setup_header(osmium::io::Header& header) const {
     }
 }
 
-void with_osm_output::setup_header(osmium::io::Header& header, const osmium::io::Header& input_header) const {
-    header.set("generator", m_generator);
-    for (const auto& h : m_output_headers) {
+void init_header(osmium::io::Header& header, const osmium::io::Header& input_header, const std::vector<std::string>& options) {
+    for (const auto& h : options) {
         if (!h.empty() && h.back() == '!') {
             std::string hc{h};
             hc.resize(h.size() - 1);
@@ -225,3 +224,8 @@ void with_osm_output::setup_header(osmium::io::Header& header, const osmium::io:
     }
 }
 
+void with_osm_output::setup_header(osmium::io::Header& header, const osmium::io::Header& input_header) const {
+    header.set("generator", m_generator);
+    init_header(header, input_header, m_output_headers);
+}
+
