@@ -4,11 +4,11 @@
 #include "command_time_filter.hpp"
 
 TEST_CASE("time-filter") {
-
-    CommandTimeFilter cmd;
+    CommandFactory factory;
+    CommandTimeFilter cmd{factory};
 
     SECTION("no parameters") {
-        REQUIRE_THROWS_AS(cmd.setup({}), argument_error);
+        REQUIRE_THROWS_AS(cmd.setup({}), const argument_error&);
     }
 
 }
